:mod:`art.estimators.poison_mitigation.neural_cleanse`
======================================================
.. automodule:: art.estimators.poison_mitigation.neural_cleanse

Keras Neural Cleanse Classifier
-------------------------------
.. autoclass:: KerasNeuralCleanse
   :members:
   :special-members: __init__
   :inherited-members:
